@@ -46,6 +46,6 @@ struct spvm_method {
 
 SPVM_METHOD* SPVM_METHOD_new(SPVM_COMPILER* compiler);
 
-int32_t SPVM_METHOD_satisfy_interface_method_requirement(SPVM_COMPILER* compiler, SPVM_BASIC_TYPE* dist_basic_type, SPVM_METHOD* dist_method, SPVM_BASIC_TYPE* src_basic_type, SPVM_METHOD* src_method, const char* type_desc);
+int32_t SPVM_METHOD_satisfy_interface_method_requirement(SPVM_COMPILER* compiler, SPVM_METHOD* dist_method, SPVM_METHOD* src_method, char* error_reason);
 
 #endif
